@@ -2,8 +2,12 @@ from .Administration import *
 from .Application import *
 from .Exceptions import *
 
-Version = "1.0.4"
+Version = "1.0.5"
 Author = "xFueY"
 Source = "https://github.com/xFueY/PyAuthGG"
+Changelog = """Version 1.0.5 - 28th December 2020
+- Added ReadMe Content
+- Fixed ResetPassword
+- Fixed ChangePassword"""
 
 HEADERS = {"Content-Type" : "application/x-www-form-urlencoded", "User-Agent" : f"PyAuthGG {Version}"}
